Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
committerCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
commitafdd54fa3720c267f30e48ed45c449d80449bac0 (patch)
tree3192044fa53f6e1fd3d1b0256963c2d4c090d700 /intern/iksolver
parent203e6ed82b444786d7999e88cebef84d6d429765 (diff)
moved source and text to american spelling
* colour -> color * centre -> center * normalise -> normalize * modelling -> modeling
Diffstat (limited to 'intern/iksolver')
-rw-r--r--intern/iksolver/test/ik_glut_test/intern/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/intern/iksolver/test/ik_glut_test/intern/main.cpp b/intern/iksolver/test/ik_glut_test/intern/main.cpp
index b8094e6cd4f..7f1cce80a7e 100644
--- a/intern/iksolver/test/ik_glut_test/intern/main.cpp
+++ b/intern/iksolver/test/ik_glut_test/intern/main.cpp
@@ -107,9 +107,9 @@ init(MT_Vector3 min,MT_Vector3 max)
/* Setup the view of the cube. */
glMatrixMode(GL_PROJECTION);
- // centre of the box + 3* depth of box
+ // center of the box + 3* depth of box
- MT_Vector3 centre = (min + max) * 0.5;
+ MT_Vector3 center = (min + max) * 0.5;
MT_Vector3 diag = max - min;
float depth = diag.length();
@@ -125,8 +125,8 @@ init(MT_Vector3 min,MT_Vector3 max)
gluLookAt(
- centre.x(), centre.y(), centre.z() + distance*depth, /* eye is at (0,0,5) */
- centre.x(), centre.y(), centre.z(), /* center is at (0,0,0) */
+ center.x(), center.y(), center.z() + distance*depth, /* eye is at (0,0,5) */
+ center.x(), center.y(), center.z(), /* center is at (0,0,0) */
0.0, 1.0, 0.); /* up is in positive Y direction */
glPushMatrix();